#!/bin/sh

echo "post-install"

# App Central extend timeout, but the timeout seems be counted from post-install, not pre-install, so move "docker pull" to post-install.

docker pull lscr.io/linuxserver/deluge:latest

echo "Completed docker pull"


CONTAINER_TEST=$(docker container ls -a | grep Deluge | awk '{print $1}')

if [ ! -z $CONTAINER_TEST ]; then
	docker rm -f $CONTAINER_TEST
fi

# This container cannot directly apply -v /usr/builtin/etc/certificate/:/config/ssl/:ro, since /config/ssl is the default certificate of Deluge, and it cannot be read-only.
# If apply this, the Deluge server cannot run up. should copy ADM certificate to this folder.

# Deluge will keep the certificate on /config/ssl folder, need to check if the certificate is updated or not. If yes, need to replace new one.
# If Deluge certificate is not existed, copy it directly.

ADM_SSL_FILE=/usr/builtin/etc/certificate/ssl.crt
ADM_KEY_FILE=/usr/builtin/etc/certificate/ssl.key

DELUGE_SSL=/share/Docker/Deluge/config/ssl
DELUGE_SSL_FILE=/share/Docker/Deluge/config/ssl/daemon.crt
DELUGE_KEY_FILE=/share/Docker/Deluge/config/ssl/daemon.key

DELUGE_WEB_CONF=/share/Docker/Deluge/config/web.conf

if [ ! -e $DELUGE_WEB_CONF ]; then
	cp -f $APKG_PKG_DIR/conf/web.conf /share/Docker/Deluge/config/

fi

if [ -e $DELUGE_SSL_FILE ]; then

	# Compare the ADM certificate and the Deluge copied one
	CERT_DIFF=$(diff -bBq $ADM_SSL_FILE $DELUGE_SSL_FILE | grep differ | awk '{print $5}')
		
	#Before create and start Deluge Container, copy the certificate if it's different with ADM certificate. cp -f (overwrite)
		
	if [ "$CERT_DIFF" == "differ" ]; then
		cp -f $ADM_SSL_FILE $DELUGE_SSL_FILE
		cp -f $ADM_KEY_FILE $DELUGE_KEY_FILE
	fi
	
else
	# If file is not existed, copy directly.
	cp -f $ADM_SSL_FILE $DELUGE_SSL_FILE
	cp -f $ADM_KEY_FILE $DELUGE_KEY_FILE
	
fi

C_UID=$(id -u admin)
ADMIN_GID=$(id -g admin)

docker create -i -t --name=Deluge \
	-p 28112:8112 \
	-p 58846:58846 \
	-e PUID=$C_UID -e PGID=$ADMIN_GID \
	-v /etc/localtime:/etc/localtime:ro \
	-v /share/Docker/Deluge/config:/config:rw \
	-v /share/Download:/downloads:rw \
	-v /share:/shared:rw \
	--restart unless-stopped \
	lscr.io/linuxserver/deluge:latest


docker start Deluge
sleep 3

case "$APKG_PKG_STATUS" in
	install)
		;;
	upgrade)
		oldim=$(docker images | grep lscr.io/linuxserver/deluge | grep none | awk '{print $3}')
		echo $oldim
		
		if [ ! -z $oldim ]; then 
			docker rmi -f $oldim
		fi

		# If the original file produced, remvoe it directly.
		if [ -e $DELUGE_SSL/daemon.pkey ]; then
			rm -f $DELUGE_SSL/daemon.pkey
			rm -f $DELUGE_SSL/daemon.cert
		fi
		;;
	*)
		;;
esac

# The followings can be removed from next release.
imold=$(docker images | grep linuxserver/deluge | grep latest | awk '{print $3}')
echo $imold
		
if [ ! -z $imold ]; then 
	docker rmi -f $imold
fi

exit 0
